@@ -1,5 +1,8 @@
 package Perinci::To::POD;
 
+our $DATE = '2015-01-02'; # DATE
+our $VERSION = '0.59'; # VERSION
+
 use 5.010001;
 use Log::Any '$log';
 use Moo;
@@ -8,8 +11,6 @@ use Locale::TextDomain::UTF8 'Perinci-To-Doc';
 
 extends 'Perinci::To::PackageBase';
 
-our $VERSION = '0.58'; # VERSION
-
 sub BUILD {
     my ($self, $args) = @_;
 }
@@ -152,7 +153,7 @@ Perinci::To::POD - Generate POD documentation for a package from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.58 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2014-12-11.
+This document describes version 0.59 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-01-02.
 
 =head1 SYNOPSIS
 
@@ -176,7 +177,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
@@ -192,7 +193,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
