@@ -1,14 +1,13 @@
 package Perinci::To::PackageBase;
 
-our $DATE = '2014-12-11'; # DATE
-our $VERSION = '0.58'; # VERSION
+our $DATE = '2015-01-02'; # DATE
+our $VERSION = '0.59'; # VERSION
 
 use 5.010;
 use Data::Dump::OneLine qw(dump1);
 use Log::Any '$log';
 use Moo;
 use Perinci::Object;
-use Perinci::ToUtil;
 
 with 'Perinci::To::Doc::Role::Section';
 
@@ -119,7 +118,7 @@ Perinci::To::PackageBase - Base class for Perinci::To::* package documentation g
 
 =head1 VERSION
 
-This document describes version 0.58 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2014-12-11.
+This document describes version 0.59 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-01-02.
 
 =for Pod::Coverage .+
 
@@ -129,7 +128,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
@@ -145,7 +144,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
